@@ -2159,7 +2159,11 @@ DescribeAvailablePatchesResultTypeDef = TypedDict(
 
 DescribeDocumentPermissionResponseTypeDef = TypedDict(
     "DescribeDocumentPermissionResponseTypeDef",
-    {"AccountIds": List[str], "AccountSharingInfoList": List["AccountSharingInfoTypeDef"]},
+    {
+        "AccountIds": List[str],
+        "AccountSharingInfoList": List["AccountSharingInfoTypeDef"],
+        "NextToken": str,
+    },
     total=False,
 )
 
